package com.ruoyi.system.service;

import com.ruoyi.common.core.domain.model.WeChatUser;
import com.ruoyi.system.domain.CpsContentInfo;
import com.ruoyi.system.domain.CpsMeetingEnterpriseTripInfo;
import com.ruoyi.system.domain.CpsMeetingUsr;

import java.util.List;

/**
 * cps_meeting_usr与会人员信息Service接口
 *
 * @author ruoyi
 * @date 2024-08-18
 */
public interface ICpsMeetingUsrService {
    /**
     * 查询cps_meeting_usr与会人员信息
     *
     * @param id cps_meeting_usr与会人员信息主键
     * @return cps_meeting_usr与会人员信息
     */
    public CpsMeetingUsr selectCpsMeetingUsrById(Long id);

    /**
     * 查询cps_meeting_usr与会人员信息列表
     *
     * @param cpsMeetingUsr cps_meeting_usr与会人员信息
     * @return cps_meeting_usr与会人员信息集合
     */
    public List<CpsMeetingUsr> selectCpsMeetingUsrList(CpsMeetingUsr cpsMeetingUsr);

    /**
     * 新增cps_meeting_usr与会人员信息
     *
     * @param cpsMeetingUsr cps_meeting_usr与会人员信息
     * @return 结果
     */
    public int insertCpsMeetingUsr(CpsMeetingUsr cpsMeetingUsr);

    /**
     * 修改cps_meeting_usr与会人员信息
     *
     * @param cpsMeetingUsr cps_meeting_usr与会人员信息
     * @return 结果
     */
    public int updateCpsMeetingUsr(CpsMeetingUsr cpsMeetingUsr);

    /**
     * 批量删除cps_meeting_usr与会人员信息
     *
     * @param ids 需要删除的cps_meeting_usr与会人员信息主键集合
     * @return 结果
     */
    public int deleteCpsMeetingUsrByIds(Long[] ids);

    /**
     * 删除cps_meeting_usr与会人员信息信息
     *
     * @param id cps_meeting_usr与会人员信息主键
     * @return 结果
     */
    public int deleteCpsMeetingUsrById(Long id);

    Boolean existCpsMeetingUsr(String openId);

    CpsMeetingUsr getWeChatUser(WeChatUser user);

    void usrRegister(CpsMeetingUsr user);

    List<CpsContentInfo> qryUsrCollectContent(String openId, String keyword);

    CpsMeetingEnterpriseTripInfo qryUsrTripContent(String openId);
}
